@@ -129,6 +129,7 @@ static const char *aa_vbgr_xpm[] = {
 #define DEFAULT_XFT_RGBA "none"
 
 #define MAX_ELEMENTS_BEFORE_SCROLLING 6
+#define BORDER 5
 
 static gboolean setting_model = FALSE;
 static gboolean setting_itheme_model = FALSE;
@@ -689,7 +690,7 @@ Itf *create_theme_dialog(McsPlugin * mcs_plugin)
     dialog->dialog_vbox1 = GTK_DIALOG(dialog->theme_dialog)->vbox;
     gtk_widget_show(dialog->dialog_vbox1);
 
-    dialog->hbox1 = gtk_hbox_new(FALSE, 5);
+    dialog->hbox1 = gtk_hbox_new(FALSE, BORDER);
     gtk_widget_show(dialog->hbox1);
     gtk_box_pack_start(GTK_BOX(dialog->dialog_vbox1), dialog->hbox1, TRUE, TRUE, 0);
     gtk_container_set_border_width(GTK_CONTAINER(dialog->hbox1), 6);
@@ -699,11 +700,15 @@ Itf *create_theme_dialog(McsPlugin * mcs_plugin)
     gtk_widget_show(dialog->themes_notebook);
     gtk_box_pack_start(GTK_BOX(dialog->hbox1), dialog->themes_notebook, TRUE, TRUE, 0);
 
-    dialog->vbox2 = gtk_vbox_new(FALSE, 5);
+    dialog->vbox2 = gtk_vbox_new(FALSE, BORDER);
     gtk_widget_show(dialog->vbox2);
 
-    dialog->frame1 = xfce_create_framebox_with_content(NULL, dialog->vbox2);
+    dialog->frame1 = gtk_frame_new (NULL);
+    gtk_frame_set_shadow_type (GTK_FRAME (dialog->frame1), GTK_SHADOW_NONE);
+    gtk_container_set_border_width (GTK_CONTAINER (dialog->frame1), BORDER);
+    gtk_container_add (GTK_CONTAINER (dialog->frame1), dialog->vbox2);
     gtk_widget_show(dialog->frame1);
+    
     dialog->theme_label = gtk_label_new_with_mnemonic(_("_Theme"));
     gtk_widget_show(dialog->theme_label);
     gtk_notebook_append_page(GTK_NOTEBOOK(dialog->themes_notebook), dialog->frame1, dialog->theme_label);
@@ -722,11 +727,15 @@ Itf *create_theme_dialog(McsPlugin * mcs_plugin)
     gtk_container_add(GTK_CONTAINER(dialog->theme_swindow), dialog->theme_treeview);
     gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(dialog->theme_treeview), FALSE);
 
-    dialog->vbox4 = gtk_vbox_new(FALSE, 5);
+    dialog->vbox4 = gtk_vbox_new(FALSE, BORDER);
     gtk_widget_show(dialog->vbox4);
 
-    dialog->frame4 = xfce_create_framebox_with_content (NULL, dialog->vbox4);
+    dialog->frame4 = gtk_frame_new (NULL);
+    gtk_frame_set_shadow_type (GTK_FRAME (dialog->frame4), GTK_SHADOW_NONE);
+    gtk_container_set_border_width (GTK_CONTAINER (dialog->frame4), BORDER);
+    gtk_container_add (GTK_CONTAINER (dialog->frame4), dialog->vbox4);
     gtk_widget_show(dialog->frame4);
+    
     dialog->icon_theme_label = gtk_label_new_with_mnemonic(_("_Icon Theme"));
     gtk_widget_show(dialog->icon_theme_label);
     gtk_notebook_append_page(GTK_NOTEBOOK(dialog->themes_notebook), dialog->frame4, dialog->icon_theme_label);
@@ -787,11 +796,11 @@ Itf *create_theme_dialog(McsPlugin * mcs_plugin)
 
     dialog->aa_framebox = xfce_create_framebox_with_content (_("Font Rendering"), dialog->aa_table);
     gtk_widget_show(dialog->aa_framebox);
-    gtk_box_pack_start(GTK_BOX(dialog->dialog_vbox1), dialog->aa_framebox, TRUE, FALSE, 5);
+    gtk_box_pack_start(GTK_BOX(dialog->dialog_vbox1), dialog->aa_framebox, TRUE, FALSE, BORDER);
 
     dialog->aa_checkbox1 = gtk_check_button_new_with_label(_("Use anti-aliasing for fonts"));
     gtk_widget_show(dialog->aa_checkbox1);
-    gtk_table_attach(GTK_TABLE(dialog->aa_table), dialog->aa_checkbox1, 0, 2, 0, 1, GTK_EXPAND | GTK_FILL, GTK_EXPAND, 5, 5);
+    gtk_table_attach(GTK_TABLE(dialog->aa_table), dialog->aa_checkbox1, 0, 2, 0, 1, GTK_EXPAND | GTK_FILL, GTK_EXPAND, BORDER, BORDER);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dialog->aa_checkbox1), (gboolean) current_xft_antialias);
     gtk_tooltips_set_tip(tooltips, dialog->aa_checkbox1, 
         _("Antialiasing is an effect that is applied to the " 
@@ -800,7 +809,7 @@ Itf *create_theme_dialog(McsPlugin * mcs_plugin)
 
     dialog->aa_checkbox2 = gtk_check_button_new_with_label(_("Use hinting:"));
     gtk_widget_show(dialog->aa_checkbox2);
-    gtk_table_attach(GTK_TABLE(dialog->aa_table), dialog->aa_checkbox2, 1, 2, 1, 2, GTK_EXPAND | GTK_FILL, GTK_EXPAND, 5, 5);
+    gtk_table_attach(GTK_TABLE(dialog->aa_table), dialog->aa_checkbox2, 1, 2, 1, 2, GTK_EXPAND | GTK_FILL, GTK_EXPAND, BORDER, BORDER);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dialog->aa_checkbox2), (gboolean) current_xft_hinting);
     gtk_tooltips_set_tip(tooltips, dialog->aa_checkbox2,
         _("Hinting is a font-rendering technique that " 
@@ -810,7 +819,7 @@ Itf *create_theme_dialog(McsPlugin * mcs_plugin)
 
     dialog->aa_omenu1 = gtk_combo_box_new_text();
     gtk_widget_show(dialog->aa_omenu1);
-    gtk_table_attach(GTK_TABLE(dialog->aa_table), dialog->aa_omenu1, 2, 3, 1, 2, GTK_EXPAND | GTK_FILL, GTK_EXPAND, 5, 5);
+    gtk_table_attach(GTK_TABLE(dialog->aa_table), dialog->aa_omenu1, 2, 3, 1, 2, GTK_EXPAND | GTK_FILL, GTK_EXPAND, BORDER, BORDER);
     gtk_widget_set_sensitive(dialog->aa_omenu1, current_xft_hinting);
 
     gtk_combo_box_append_text(GTK_COMBO_BOX(dialog->aa_omenu1), _("Slight"));
@@ -821,7 +830,7 @@ Itf *create_theme_dialog(McsPlugin * mcs_plugin)
 
     dialog->aa_checkbox3 = gtk_check_button_new_with_label(_("Use sub-pixel hinting:"));
     gtk_widget_show(dialog->aa_checkbox3);
-    gtk_table_attach(GTK_TABLE(dialog->aa_table), dialog->aa_checkbox3, 1, 2, 2, 3, GTK_EXPAND | GTK_FILL, GTK_EXPAND, 5, 5);
+    gtk_table_attach(GTK_TABLE(dialog->aa_table), dialog->aa_checkbox3, 1, 2, 2, 3, GTK_EXPAND | GTK_FILL, GTK_EXPAND, BORDER, BORDER);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dialog->aa_checkbox3), (gboolean) (strcmp(current_xft_rgba, "none") != 0));
     gtk_tooltips_set_tip(tooltips, dialog->aa_checkbox3, 
         _("Select one of the options to specify the subpixel "
@@ -831,7 +840,7 @@ Itf *create_theme_dialog(McsPlugin * mcs_plugin)
     dialog->aa_omenu2_list = gtk_list_store_new(2, GDK_TYPE_PIXBUF, G_TYPE_STRING);
     dialog->aa_omenu2 = gtk_combo_box_new_with_model(GTK_TREE_MODEL(dialog->aa_omenu2_list));
     gtk_widget_show(dialog->aa_omenu2);
-    gtk_table_attach(GTK_TABLE(dialog->aa_table), dialog->aa_omenu2, 2, 3, 2, 3, GTK_EXPAND | GTK_FILL, GTK_EXPAND, 5, 5);
+    gtk_table_attach(GTK_TABLE(dialog->aa_table), dialog->aa_omenu2, 2, 3, 2, 3, GTK_EXPAND | GTK_FILL, GTK_EXPAND, BORDER, BORDER);
     gtk_widget_set_sensitive(dialog->aa_omenu2, strcmp(current_xft_rgba, "none") != 0);
 
     cell[0] = gtk_cell_renderer_pixbuf_new();
